@@ -2,7 +2,13 @@
 from .base import Converter
 from ...helpers import iterate_files
 
-from collections import MutableMapping
+try:
+    # python 3.x: Import ABC from collections.abc
+    from collections.abc import MutableMapping
+except ImportError:
+    # Python 2.x: Import ABC from collections
+    from collections import MutableMapping
+
 from csv import writer as csv_writer, excel
 
 
@@ -45,7 +51,7 @@ class CsvConverter(Converter):
     ]
 
     def process(self, files):
-        writer = csv_writer(self.fout, dialect=excel)
+        writer = csv_writer(self.fout, dialect=excel, lineterminator='\n')
 
         # Write the header
         writer.writerow(self.fields)
