@@ -13,7 +13,7 @@ class Stream:
         self.api_key = api_key
         self.proxies = proxies
 
-    def _create_stream(self, name, timeout=None):
+    def _create_stream(self, name, query=None, timeout=None):
         params = {
             'key': self.api_key,
         }
@@ -30,6 +30,9 @@ class Stream:
         if timeout:
             params['heartbeat'] = False
 
+        if query is not None:
+            params['query'] = query
+
         try:
             while True:
                 req = requests.get(stream_url, params=params, stream=True, timeout=timeout,
@@ -60,7 +63,7 @@ class Stream:
         return req
 
     def _iter_stream(self, stream, raw):
-        for line in stream.iter_lines(decode_unicode=True):
+        for line in stream.iter_lines():
             # The Streaming API sends out heartbeat messages that are newlines
             # We want to ignore those messages since they don't contain any data
             if line:
@@ -113,6 +116,18 @@ class Stream:
         for line in self._iter_stream(stream, raw):
             yield line
 
+    def custom(self, query, raw=False, timeout=None):
+        """
+        A filtered version of the "banners" stream to only return banners that match the query of interest. The query
+        can vary and mix-match with different arguments (ports, tags, vulns, etc).
+
+        :param query: A space-separated list of key:value filters query to return banner data on.
+        :type query: string
+        """
+        stream = self._create_stream('/shodan/custom', query=query, timeout=timeout)
+        for line in self._iter_stream(stream, raw):
+            yield line
+
     def ports(self, ports, raw=False, timeout=None):
         """
         A filtered version of the "banners" stream to only return banners that match the ports of interest.
